==> SimpleMailer-0.80.tar.bz2: SimpleMailer-0.80/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/FetchTransaction.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2011 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal sealed class FetchTransaction<TMessageAttribute> :
    FetchStoreTransactionBase<TMessageAttribute>,
    IImapExtension
    where TMessageAttribute : ImapMessageAttributeBase
  {
    IEnumerable<ImapCapability> IImapExtension.RequiredCapabilities {
      get
      {
        if (fetchModifiersCapabilityRequirement != null)
          yield return fetchModifiersCapabilityRequirement;
      }
    }

    public FetchTransaction(ImapConnection connection, bool uid, ImapCapability fetchModifiersCapabilityRequirement)
      : base(connection)
    {
      this.uid = uid;
      this.fetchModifiersCapabilityRequirement = fetchModifiersCapabilityRequirement;
    }

    // RFC 4466 - Collected Extensions to IMAP4 ABNF
    // http://tools.ietf.org/html/rfc4466
    // 2.4. Extensions to FETCH and UID FETCH Commands
    //    Arguments:  sequence set
    //                message data item names or macro
    //                OPTIONAL fetch modifiers
    //    Responses:  untagged responses: FETCH
    //    Result:     OK - fetch completed
    //                NO - fetch error: cannot fetch that data
    //                BAD - command unknown or arguments invalid
    protected override ImapCommand PrepareCommand()
    {
#if DEBUG
      if (!RequestArguments.ContainsKey("sequence set") ||
          !RequestArguments.ContainsKey("message data item names or macro")) {
        FinishError(ImapCommandResultCode.RequestError, "arguments 'sequence set' and 'message data item names or macro' must be setted");
        return null;
      }
#endif

      // FETCH / UID FETCH
      ImapString fetchModifiers;

      if (RequestArguments.TryGetValue("fetch modifiers", out fetchModifiers))
        return Connection.CreateCommand(uid ? "UID FETCH" : "FETCH",
                                        RequestArguments["sequence set"],
                                        RequestArguments["message data item names or macro"],
                                        fetchModifiers);
      else
        return Connection.CreateCommand(uid ? "UID FETCH" : "FETCH",
                                        RequestArguments["sequence set"],
                                        RequestArguments["message data item names or macro"]);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok)
        Finish(CreateResult(tagged));
      else
        base.OnTaggedStatusResponseReceived(tagged);
    }

    private readonly bool uid;
    private /*readonly*/ ImapCapability fetchModifiersCapabilityRequirement;
  }
}

==> SimpleMailer-0.90.tar.bz2: SimpleMailer-0.90/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/FetchTransaction.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal sealed class FetchTransaction<TMessageAttribute> :
    FetchStoreTransactionBase<TMessageAttribute>,
    IImapExtension
    where TMessageAttribute : ImapMessageAttributeBase
  {
    IEnumerable<ImapCapability> IImapExtension.RequiredCapabilities {
      get
      {
        if (fetchModifiersCapabilityRequirement != null)
          yield return fetchModifiersCapabilityRequirement;
      }
    }

    public FetchTransaction(ImapConnection connection,
                            bool retrieveMessageAttributes,
                            long expectedMessageCount,
                            bool uid,
                            ImapCapability fetchModifiersCapabilityRequirement)
      : base(connection, retrieveMessageAttributes, expectedMessageCount)
    {
      this.uid = uid;
      this.fetchModifiersCapabilityRequirement = fetchModifiersCapabilityRequirement;
    }

    // RFC 4466 - Collected Extensions to IMAP4 ABNF
    // http://tools.ietf.org/html/rfc4466
    // 2.4. Extensions to FETCH and UID FETCH Commands
    //    Arguments:  sequence set
    //                message data item names or macro
    //                OPTIONAL fetch modifiers
    //    Responses:  untagged responses: FETCH
    //    Result:     OK - fetch completed
    //                NO - fetch error: cannot fetch that data
    //                BAD - command unknown or arguments invalid
    protected override ImapCommand PrepareCommand()
    {
#if DEBUG
      if (!RequestArguments.ContainsKey("sequence set") ||
          !RequestArguments.ContainsKey("message data item names or macro")) {
        FinishError(ImapCommandResultCode.RequestError, "arguments 'sequence set' and 'message data item names or macro' must be setted");
        return null;
      }
#endif

      // FETCH / UID FETCH
      ImapString fetchModifiers;

      if (RequestArguments.TryGetValue("fetch modifiers", out fetchModifiers))
        return Connection.CreateCommand(uid ? "UID FETCH" : "FETCH",
                                        RequestArguments["sequence set"],
                                        RequestArguments["message data item names or macro"],
                                        fetchModifiers);
      else
        return Connection.CreateCommand(uid ? "UID FETCH" : "FETCH",
                                        RequestArguments["sequence set"],
                                        RequestArguments["message data item names or macro"]);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok)
        Finish(CreateResult(tagged));
      else
        base.OnTaggedStatusResponseReceived(tagged);
    }

    private readonly bool uid;
    private /*readonly*/ ImapCapability fetchModifiersCapabilityRequirement;
  }
}
